## v1.0.0 (2024-09-15)

### Feat

- add `--yes` flag for automatically confirmation

### Fix

- correct default arguments for included and excluded keys to empty list
- use python 3.8 compatible type annotations
- update pandera to a version supporting NumPy 2

## v1.0.0rc5 (2024-09-13)

### Feat

- allows to provide returned keys for custom data loaders

### Fix

- dynamically retrieve version from package meta data

## v1.0.0-rc4 (2023-06-14)

## v1.0.0-rc3 (2023-03-21)

## v1.0.0-rc2 (2023-02-16)

## v1.0.0-rc1 (2023-02-13)

## v0.0.7 (2023-02-07)

## v0.0.6 (2022-12-16)

## v0.0.5 (2022-12-01)

## v0.0.4 (2022-12-01)

## v0.0.3 (2022-12-01)

## v0.0.2 (2022-11-29)
